package GII::Event::Command::DevInfo;

=head1 NAME

GII::Event::Command::DevInfo - Perl class for gii_cmddata_devinfo structures.

=head1 SYNOPSIS

    use GII::Event::Command::DevInfo;

    $ev = new GII::Event::Command::DevInfo;

    $ev->send($input);

    $longname = $ev->longname();
    $ev->longname($longname);

    $shortname = $ev->shortname();
    $ev->shortname($shortname);

    $mask = $ev->mask();
    $ev->mask($mask);

    $buttons = $ev->buttons();
    $ev->buttons($buttons);

    $axes = $ev->axes();
    $ev->axes($axes);

=head1 DESCRIPTION

The GII::Event::Command::DevInfo subclass provides simple methods to 
access the extra members of a LibGII gii_cmddata_devinfo structure 
which cannot be accessed via the methods in the class GII::Event::Command.

=cut

use strict;
use vars qw($VERSION @ISA);
use GII::Event::Command;

require DynaLoader;
require AutoLoader;

@ISA = qw(AutoLoader DynaLoader GII::Event::Command);

$VERSION = '0.01';

bootstrap GII::Event::Command::DevInfo $VERSION;

=head1 Methods

The extra methods and differences between GII::Event::Command methods 
and the ones provided in the GII::Event::Command::DevInfo class are 
as follows:

=head2 new

The GII::Event::Command::Devinfo constructor takes all the same arguments
as the GII::Event::Command constructor, and treats them the same with the
exception that it does not do any automagical subclassing and it has
a strictly fixed size.  All calls to this constructor will either fail 
or allocate/reuse a gii_cmd_event/gii_cmddata_devinfo structure.

=cut


=head2 longname

With no arguments, gets a string containing the verbose name of the device.
With an argument, sets said string and returns the string set.  The 
string is maximum 75 characters.

=cut

sub longname {
    my ($this) = shift();
    if (@_ + 0) {
	return set_longname($this->{obj}, shift());
    }
    return get_longname($this->{obj});
}

=head2 shortname

With no arguments, gets a string containing the compact name of the device.
With an argument, sets said string and returns the string set.  The 
string is maximum 5 characters.

=cut

sub shortname {
    my ($this) = shift();
    if (@_ + 0) {
	return set_shortname($this->{obj}, shift());
    }
    return get_shortname($this->{obj});
}

=head2 mask

With no arguments, gets a gii_event_mask which tells what events the 
issuing device can emit.  With an argument, sets said mask and returns 
the mask set.

=cut

sub mask {
    my ($this) = shift();
    if (@_ + 0) {
	return set_mask($this->{obj}, shift());
    }
    return get_mask($this->{obj});
}


=head2 buttons

With no arguments, gets the number of buttons the device has.  With 
an argument, sets said number and returns the number set.

=cut

sub buttons {
    my ($this) = shift();
    if (@_ + 0) {
	return set_buttons($this->{obj}, shift());
    }
    return get_buttons($this->{obj});
}

=head2 axes

With no arguments, gets the number of axes the device has.  With 
an argument, sets said number and returns the number set.

=cut

sub axes {
    my ($this) = shift();
    if (@_ + 0) {
	return set_axes($this->{obj}, shift());
    }
    return get_axes($this->{obj});
}


=head2 size

Size always returns a fixed size, and when called with a parameter
will always set the event size to the same value.  There is no negotiation 
of the size of a GII::Event::Command::DevInfo.  If you are recycling
an old event structure, calling the size method will any defined argument 
will ensure the event size is set correctly.

=cut

# size method is inherited, C routines are overloaded.

=head2 data_size

data_size always returns a fixed size, and when called with a parameter
will always set the command data size to the same value.  There is no 
negotiation of the size of a GII::Event::Command::DevInfo.  If you 
are recycling an old event structure, calling the data_size method with
any defined argument will ensure that both the event size and the command 
data size is set correctly.

=cut

# data_size method is inherited, C routines are overloaded.

1;
__END__

=head1 AUTHOR

Brian S. Julin <bri@calyx.com>

=head1 SEE ALSO

GII::Event::Command(3pm), GII::Event(3pm), GII(3pm), perl(1).

=cut
